server_client_20141231_085104

### config2 : test_redlining

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 7.42732906342 sec | 12.6505758762 sec

Error message: server latency too high while sending 10000 integers

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 51.83 | 0.49 | 0.12 | 0.23 | 0.29 | 0.43 | 0.55 | 3.78 | 2.58
qps | 300.00 | 200.20 | 150.00 | 186.00 | 215.00 | 266.00 | 283.00 | 296.60 | 55.54

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0
latency | 4816.73 | 4816.73 | 4816.73 | 4816.73 | 4816.73 | 4816.73 | 4816.73 | 4816.73 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | qps | mean lt 7.0 | 200.2
server1-perf | latency | p50 lt 0.3 | 0.226
server1-perf | latency | mean lt 0.33 | 0.485572427572
server2-perf | qps | mean lt 7.0 | None
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
client1-perf | qps | mean lt 2.0 | 1.0
client1-perf | latency | p50 lt 22.0 | 4816.734
client1-perf | latency | mean lt 35.0 | 4816.734
client2-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None